@@ -110,7 +110,7 @@ def get_augment_instruction(instruction: str, content: str) -> str:
     return f"Apply the following instruction to the `User Content` in the `# User Content` section.\n\n# Instruction\n\n{instruction}\n\n# User Content\n\n{content}"
 
 def get_statusbar_text():
-    return " [esc-m] menu [ctrl+k] help "
+    return " [esc-m] menu [ctrl+y] help "
 
 def get_statusbar_right_text():
     return " {}:{}  ".format(
@@ -388,7 +388,7 @@ def _(event):
 
 # Basic
 # help
-@bindings.add("c-k")
+@bindings.add("c-y")
 def _(_):
     do_help()
 # quit
@@ -570,16 +570,19 @@ def _(event):
 #
 
 def do_save_file():
-    if ApplicationState.current_path:
-        try:
-            with open(ApplicationState.current_path, "w", encoding="utf-8") as fileObj:
-                fileObj.write(text_field.text)
-            ApplicationState.saved_text = text_field.text
-        except OSError as e:
-            show_message("Error", f"{e}")
+    if ApplicationState.exit_without_saving:
+        get_app().exit()
     else:
-        do_save_as_file()
-    update_title()
+        if ApplicationState.current_path:
+            try:
+                with open(ApplicationState.current_path, "w", encoding="utf-8") as fileObj:
+                    fileObj.write(text_field.text)
+                ApplicationState.saved_text = text_field.text
+            except OSError as e:
+                show_message("Error", f"{e}")
+        else:
+            do_save_as_file()
+        update_title()
 
 def do_save_as_file():
     async def coroutine():
@@ -737,9 +740,9 @@ def do_add_spaces(event=None):
     buffer = event.app.current_buffer if event is not None else text_field.buffer
     buffer.insert_text("    ")
 
-def do_go_to_end_once(_):
+def do_go_to_end_once(cursor_position):
     if ApplicationState.allow_go_to_end:
-        text_field.buffer.cursor_position = len(text_field.text)
+        text_field.buffer.cursor_position = cursor_position
         ApplicationState.allow_go_to_end = False
 
 def do_go_to():
@@ -1015,7 +1018,7 @@ layout = Layout(root_container, focused_element=text_field)
 def update_title(customTitle=None):
     set_title(customTitle if customTitle is not None else f'''eTextEdit - {os.path.basename(ApplicationState.current_path) if ApplicationState.current_path else "NEW"}''')
 
-def launch(input_text=None, filename=None, exitWithoutSaving=False, customTitle=None, startAtEnd=False):
+def get_editor_app(input_text=None, filename=None, exitWithoutSaving=False, startAt=0):
     ApplicationState.exit_without_saving = exitWithoutSaving
     if filename and os.path.isfile(filename):
         try:
@@ -1028,7 +1031,6 @@ def launch(input_text=None, filename=None, exitWithoutSaving=False, customTitle=
     if filename:
         ApplicationState.current_path = filename
         ApplicationState.saved_text = fileText
-    update_title(customTitle)
     if filename and input_text:
         # append file text with input text
         text_field.text = f"{fileText}\n{input_text}"
@@ -1038,7 +1040,7 @@ def launch(input_text=None, filename=None, exitWithoutSaving=False, customTitle=
         text_field.text = input_text
     # create a custom input to work with stdin without EOFError
     input = create_input(always_prefer_tty=True)
-    application = Application(
+    return Application(
         layout=layout,
         enable_page_navigation_bindings=True,
         style=combined_style,
@@ -1046,12 +1048,23 @@ def launch(input_text=None, filename=None, exitWithoutSaving=False, customTitle=
         full_screen=True,
         input=input,
         clipboard=ApplicationState.clipboard,
-        before_render=do_go_to_end_once if startAtEnd else None,
+        before_render=lambda _: do_go_to_end_once(startAt) if startAt else None,
     )
+
+def launch(input_text=None, filename=None, exitWithoutSaving=False, customTitle=None, startAt=0):
+    update_title(customTitle)
+    application = get_editor_app(input_text=input_text, filename=filename, exitWithoutSaving=exitWithoutSaving, startAt=startAt)
     application.run()
     clear_title()
     return text_field.text
 
+async def launch_async(input_text=None, filename=None, exitWithoutSaving=False, customTitle=None, startAt=0):
+    update_title(customTitle)
+    application = get_editor_app(input_text=input_text, filename=filename, exitWithoutSaving=exitWithoutSaving, startAt=startAt)
+    await application.run_async()
+    clear_title()
+    return text_field.text
+
 def main():
     os.chdir(startupPath)
     if len(sys.argv) > 1:
